@@ -4,17 +4,16 @@
 """Agreement resource"""
 
 
-from acapi2.resources.acquiaresource import AcquiaResource
-from requests.sessions import Session
 from requests.exceptions import RequestException
+from requests.sessions import Session
+
+from acapi2.resources.acquiaresource import AcquiaResource
 
 
 class Agreement(AcquiaResource):
-
-    def __init__(self, uri: str,
-                 api_key: str,
-                 api_secret: str,
-                 *args, **kwargs) -> None:
+    def __init__(
+        self, uri: str, api_key: str, api_secret: str, *args, **kwargs
+    ) -> None:
         super().__init__(uri, api_key, api_secret, *args, **kwargs)
 
     def accept(self) -> Session:
