@@ -3,17 +3,15 @@
 
 """Agreement list"""
 
+from acapi2.exceptions import AcquiaCloudNoDataException
 from acapi2.resources.acquialist import AcquiaList
 from acapi2.resources.agreement import Agreement
-from acapi2.exceptions import AcquiaCloudNoDataException
 
 
 class AgreementList(AcquiaList):
-
-    def __init__(self, uri: str,
-                 api_key: str,
-                 api_secret: str,
-                 *args, **kwargs) -> None:
+    def __init__(
+        self, uri: str, api_key: str, api_secret: str, *args, **kwargs
+    ) -> None:
 
         super().__init__(uri, api_key, api_secret, *args, **kwargs)
         self.fetch()
@@ -27,11 +25,10 @@ class AgreementList(AcquiaList):
         else:
             for agreement in agr_items:
                 agr_uri = agreement["_links"]["self"]["href"]
-                self.__setitem__(agreement["uuid"],
-                                 Agreement(agr_uri,
-                                           self.api_key,
-                                           self.api_secret)
-                                 )
+                self.__setitem__(
+                    agreement["uuid"],
+                    Agreement(agr_uri, self.api_key, self.api_secret),
+                )
 
     @property
     def base_uri(self) -> str:
