@@ -1,10 +1,10 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
+import unittest
 from unittest.mock import patch
 
 import requests
 import requests_mock
-import unittest
 
 from acapi2.http_request import HttpRequest
 from acapi2.resources.acquiadata import AcquiaData
@@ -24,42 +24,44 @@ class TestAcquiaData(unittest.TestCase):
 
         mocker.register_uri("GET", uri, status_code=404)
 
-        acquia_data = AcquiaData(
-            uri, self.api_key, self.api_secret
-        )
+        acquia_data = AcquiaData(uri, self.api_key, self.api_secret)
 
         with self.assertRaises(requests.HTTPError):
             acquia_data.request()
 
     def test_retry_and_get(self, mocker):
-        mocker.register_uri("GET", self.endpoint,
-                            [{"status_code": 500},
-                             {"status_code": 503},
-                             {"status_code": 502},
-                             {"status_code": 200}])
-
-        acquia_data = AcquiaData(
-            self.endpoint, self.api_key, self.api_secret
+        mocker.register_uri(
+            "GET",
+            self.endpoint,
+            [
+                {"status_code": 500},
+                {"status_code": 503},
+                {"status_code": 502},
+                {"status_code": 200},
+            ],
         )
 
+        acquia_data = AcquiaData(self.endpoint, self.api_key, self.api_secret)
+
         self.assertEqual(acquia_data.request().status_code, 200)
 
     def test_unauthorised_request(self, mocker):
         mocker.register_uri("GET", self.endpoint, status_code=403)
-        acquia_data = AcquiaData(
-            self.endpoint, self.api_key, self.api_secret
-        )
+        acquia_data = AcquiaData(self.endpoint, self.api_key, self.api_secret)
 
         with self.assertRaises(requests.HTTPError):
             acquia_data.request()
 
     def test_post_request(self, mocker):
         uri = self.endpoint + "organizations"
-        mocker.register_uri("POST", uri, status_code=200,
-                            json={"message": "Oganization created."})
+        mocker.register_uri(
+            "POST",
+            uri,
+            status_code=200,
+            json={"message": "Oganization created."},
+        )
 
-        acquia_data = AcquiaData(uri, self.api_key,
-                                 self.api_secret)
+        acquia_data = AcquiaData(uri, self.api_key, self.api_secret)
 
         rdata = {"name": "A Random name"}
         response = acquia_data.request(method="POST", data=rdata)
@@ -77,13 +79,13 @@ class TestAcquiaData(unittest.TestCase):
             "admins_total": "2",
             "users_total": "82",
             "teams_total": "13",
-            "roles_total": "4"
+            "roles_total": "4",
         }
-        mocker.register_uri("DELETE", uri, status_code=202,
-                            json=acquia_response)
+        mocker.register_uri(
+            "DELETE", uri, status_code=202, json=acquia_response
+        )
 
-        acquia_data = AcquiaData(uri, self.api_key,
-                                 self.api_secret)
+        acquia_data = AcquiaData(uri, self.api_key, self.api_secret)
         response = acquia_data.request(method="DELETE")
 
         self.assertEqual(response.status_code, 202)
@@ -94,11 +96,10 @@ class TestAcquiaData(unittest.TestCase):
     def test_request_backoff(self, mocker, request_do_mock):
         request_do_mock.side_effect = [
             requests.exceptions.ConnectionError(),
-            requests_mock.create_response(requests.Request())
+            requests_mock.create_response(requests.Request()),
         ]
 
-        acquia_data = AcquiaData(self.endpoint, self.api_key,
-                                 self.api_secret)
+        acquia_data = AcquiaData(self.endpoint, self.api_key, self.api_secret)
         acquia_data.request()
 
         assert request_do_mock.call_count == 2
